_PyFunction_FastCallDict() supports keyword args

Issue #27809:

* Rename _PyFunction_FastCall() to _PyFunction_FastCallDict()
* Rename _PyCFunction_FastCall() to _PyCFunction_FastCallDict()
*  _PyFunction_FastCallDict() now supports keyword arguments
diff --git a/Objects/methodobject.c b/Objects/methodobject.c
index 0e26232..edb2fc0 100644
--- a/Objects/methodobject.c
+++ b/Objects/methodobject.c
@@ -146,8 +146,8 @@
 }
 
 PyObject *
-_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, int nargs,
-                      PyObject *kwargs)
+_PyCFunction_FastCallDict(PyObject *func_obj, PyObject **args, int nargs,
+                          PyObject *kwargs)
 {
     PyCFunctionObject* func = (PyCFunctionObject*)func_obj;
     PyCFunction meth = PyCFunction_GET_FUNCTION(func);
@@ -155,7 +155,7 @@
     PyObject *result;
     int flags;
 
     /* _PyCFunction_FastCall() must not be called with an exception set,
        because it may clear it (directly or indirectly) and so the
        caller loses its exception */
     assert(!PyErr_Occurred());
@@ -155,7 +155,7 @@
     int flags;
 
-    /* _PyCFunction_FastCall() must not be called with an exception set,
+    /* _PyCFunction_FastCallDict() must not be called with an exception set,
        because it may clear it (directly or indirectly) and so the
        caller loses its exception */